# coding=utf-8
# --------------------------------------------------------------------------
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.
# --------------------------------------------------------------------------

from msrest.serialization import Model


class ActionableBillCounts(Model):
    """ActionableBillCounts.

    :param export_hold_count: Count of bills Held from Export
    :type export_hold_count: int
    :param ap_export_count: Count of bills Waiting for Export to AP
    :type ap_export_count: int
    :param gl_export_count: Count of bills Waiting for Export to GL
    :type gl_export_count: int
    :param approval_count: Count of bills which are Not Approved
    :type approval_count: int
    :param audit_problem_count: Count of bills with unresolved flags
    :type audit_problem_count: int
    :param created_last_seven_days_count: Count of bills created in the last
     seven days
    :type created_last_seven_days_count: int
    """

    _attribute_map = {
        'export_hold_count': {'key': 'exportHoldCount', 'type': 'int'},
        'ap_export_count': {'key': 'apExportCount', 'type': 'int'},
        'gl_export_count': {'key': 'glExportCount', 'type': 'int'},
        'approval_count': {'key': 'approvalCount', 'type': 'int'},
        'audit_problem_count': {'key': 'auditProblemCount', 'type': 'int'},
        'created_last_seven_days_count': {'key': 'createdLastSevenDaysCount', 'type': 'int'},
    }

    def __init__(self, **kwargs):
        super(ActionableBillCounts, self).__init__(**kwargs)
        self.export_hold_count = kwargs.get('export_hold_count', None)
        self.ap_export_count = kwargs.get('ap_export_count', None)
        self.gl_export_count = kwargs.get('gl_export_count', None)
        self.approval_count = kwargs.get('approval_count', None)
        self.audit_problem_count = kwargs.get('audit_problem_count', None)
        self.created_last_seven_days_count = kwargs.get('created_last_seven_days_count', None)
